# SearchSource: OpenAlex

Note: This document is currently under development. It will contain the following elements.

- description
- coverage (disciplines, types of work)
- supported (details): run_search (including updates), load,  prep (including get_masterdata)

## Add the search source

```
colrev search -a colrev.open_alex -p "..."
```

To test the metadata provided for a particular `open_alex_id` use:
```
https://api.openalex.org/works/OPEN_ALEX_ID
```

## Links

- [OpenAlex](https://openalex.org/)
- [License](https://docs.openalex.org/additional-help/faq#how-is-openalex-licensed)
